@@ -4,27 +4,27 @@ from django.conf import settings
 from django.http import FileResponse, Http404, HttpRequest
 from django.views import View
 
+from .settings import PARAM, TIMEOUT
 from .storage import TitofistoStorage
 
-_DEFAULT_PARAM_PREFIX = "titofisto_"
-_DEFAULT_TIMEOUT = 60 * 60
-
 
 class TitofistoMediaView(View):
     def get(self, request: HttpRequest, name: str) -> FileResponse:
-        # Get storage and determine settings
+        # Get storage
         storage = TitofistoStorage()
-        param_prefix = getattr(settings, "TITOFISTO_PARAM_PREFIX", _DEFAULT_PARAM_PREFIX)
 
-        # Inspect URL parameters for completeness
-        ts = request.GET.get(f"{param_prefix}ts", None)
-        token = request.GET.get(f"{param_prefix}token", None)
-        if ts is None or token is None:
+        # Inspect URL parameter for completeness and extract timestamp
+        token = request.GET.get(PARAM, None)
+        if token is None:
+            raise Http404()
+        try:
+            ts = int(token[64:], 16)
+        except ValueError:
             raise Http404()
 
         # Compute expected token for filename
         try:
-            expected_token, _ = storage.get_token(name, ts)
+            expected_token = storage.get_token(name, ts)
         except FileNotFoundError:
             raise Http404()
 
@@ -33,9 +33,8 @@ class TitofistoMediaView(View):
             raise Http404()
 
         # Calculate time difference if timeout is set
-        now = datetime.now().strftime("%s")
-        timeout = getattr(settings, "TITOFISTO_TIMEOUT", _DEFAULT_TIMEOUT)
-        if timeout is not None and int(now) - int(ts) > timeout:
+        now = int(datetime.now().strftime("%s"))
+        if TIMEOUT is not None and now - ts > TIMEOUT:
             raise Http404()
 
         # Finally, serve file from disk if all checks passed
